@@ -456,14 +456,13 @@ generated_code.append("# LICENSE file in the root directory of this source tree.
 generated_code.append("")
 generated_code.append("")
 generated_code.append("# This file was generated by libcst.codegen.gen_matcher_classes")
-generated_code.append("from abc import ABC")
 generated_code.append("from dataclasses import dataclass")
 generated_code.append("from typing import Callable, Sequence, Union")
 generated_code.append("from typing_extensions import Literal")
 generated_code.append("import libcst as cst")
 generated_code.append("")
 generated_code.append(
-    "from libcst.matchers._matcher_base import BaseMatcherNode, DoNotCareSentinel, DoNotCare, OneOf, AllOf, DoesNotMatch, MatchIfTrue, MatchRegex, MatchMetadata, MatchMetadataIfTrue, ZeroOrMore, AtLeastN, ZeroOrOne, AtMostN, SaveMatchedNode, extract, extractall, findall, matches, replace"
+    "from libcst.matchers._matcher_base import AbstractBaseMatcherNodeMeta, BaseMatcherNode, DoNotCareSentinel, DoNotCare, TypeOf, OneOf, AllOf, DoesNotMatch, MatchIfTrue, MatchRegex, MatchMetadata, MatchMetadataIfTrue, ZeroOrMore, AtLeastN, ZeroOrOne, AtMostN, SaveMatchedNode, extract, extractall, findall, matches, replace"
 )
 all_exports.update(
     [
@@ -477,6 +476,7 @@ all_exports.update(
         "MatchRegex",
         "MatchMetadata",
         "MatchMetadataIfTrue",
+        "TypeOf",
         "ZeroOrMore",
         "AtLeastN",
         "ZeroOrOne",
@@ -504,10 +504,15 @@ all_exports.update(
     ]
 )
 
+generated_code.append("")
+generated_code.append("")
+generated_code.append("class _NodeABC(metaclass=AbstractBaseMatcherNodeMeta):")
+generated_code.append("    __slots__ = ()")
+
 for base in typeclasses:
     generated_code.append("")
     generated_code.append("")
-    generated_code.append(f"class {base.__name__}(ABC):")
+    generated_code.append(f"class {base.__name__}(_NodeABC):")
     generated_code.append("    pass")
     all_exports.add(base.__name__)
 
@@ -553,7 +558,7 @@ for node in all_libcst_nodes:
 
     # Add special metadata field
     generated_code.append(
-        f"    metadata: Union[MetadataMatchType, DoNotCareSentinel, OneOf[MetadataMatchType], AllOf[MetadataMatchType]] = DoNotCare()"
+        "    metadata: Union[MetadataMatchType, DoNotCareSentinel, OneOf[MetadataMatchType], AllOf[MetadataMatchType]] = DoNotCare()"
     )
 
 
