@@ -1018,8 +1018,8 @@ class ScopeProviderTest(UnitTest):
     def test_annotation_access(self) -> None:
         m, scopes = get_scope_metadata_provider(
             """
-                from typing import Literal, TypeVar
-                from a import A, B, C, D, E, F
+                from typing import Literal, NewType, Optional, TypeVar
+                from a import A, B, C, D, E, F, G, H
                 def x(a: A):
                     pass
                 def y(b: "B"):
@@ -1029,6 +1029,8 @@ class ScopeProviderTest(UnitTest):
                 DType = TypeVar("DType", bound=D)
                 EType = TypeVar("EType", bound="E")
                 FType = TypeVar("F")
+                GType = NewType("GType", "Optional[G]")
+                HType = Optional["H"]
             """
         )
         imp = ensure_type(
@@ -1068,6 +1070,18 @@ class ScopeProviderTest(UnitTest):
         self.assertIsInstance(assignment, Assignment)
         self.assertEqual(len(assignment.references), 0)
 
+        assignment = list(scope["G"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 1)
+        references = list(assignment.references)
+        self.assertTrue(references[0].is_annotation)
+
+        assignment = list(scope["H"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 1)
+        references = list(assignment.references)
+        self.assertTrue(references[0].is_annotation)
+
     def test_node_of_scopes(self) -> None:
         m, scopes = get_scope_metadata_provider(
             """
